"""
Unit tests for Trasor.io SDK exceptions
"""

import pytest
from trasorio.exceptions import TrasorError, AuthenticationError, ValidationError, APIError


class TestExceptions:
    """Test suite for SDK exceptions"""

    def test_trasor_error_inheritance(self):
        """Test that TrasorError is base exception"""
        error = TrasorError("Test error")
        assert isinstance(error, Exception)
        assert str(error) == "Test error"

    def test_authentication_error_inheritance(self):
        """Test that AuthenticationError inherits from TrasorError"""
        error = AuthenticationError("Auth failed")
        assert isinstance(error, TrasorError)
        assert isinstance(error, Exception)
        assert str(error) == "Auth failed"

    def test_validation_error_inheritance(self):
        """Test that ValidationError inherits from TrasorError"""
        error = ValidationError("Validation failed")
        assert isinstance(error, TrasorError)
        assert isinstance(error, Exception)
        assert str(error) == "Validation failed"

    def test_api_error_inheritance(self):
        """Test that APIError inherits from TrasorError"""
        error = APIError("API failed")
        assert isinstance(error, TrasorError)
        assert isinstance(error, Exception)
        assert str(error) == "API failed"

    def test_exception_hierarchy(self):
        """Test exception hierarchy for proper catching"""
        # Test that specific exceptions can be caught by base class
        try:
            raise AuthenticationError("Auth error")
        except TrasorError as e:
            assert isinstance(e, AuthenticationError)
            assert str(e) == "Auth error"
        
        try:
            raise ValidationError("Validation error")
        except TrasorError as e:
            assert isinstance(e, ValidationError)
            assert str(e) == "Validation error"
        
        try:
            raise APIError("API error")
        except TrasorError as e:
            assert isinstance(e, APIError)
            assert str(e) == "API error"